summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmbicubicpatchedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmbicubicpatchedit.h')
-rw-r--r--kpovmodeler/pmbicubicpatchedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmbicubicpatchedit.h b/kpovmodeler/pmbicubicpatchedit.h
index cb27810f..bdf2a971 100644
--- a/kpovmodeler/pmbicubicpatchedit.h
+++ b/kpovmodeler/pmbicubicpatchedit.h
@@ -43,9 +43,9 @@ class PMBicubicPatchEdit : public PMGraphicalObjectEdit
typedef PMGraphicalObjectEdit Base;
public:
/**
* Creates a PMBicubicPatchEdit with tqparent and name
*/
- PMBicubicPatchEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBicubicPatchEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -43,9 +43,9 @@ class PMBicubicPatchEdit : public PMGraphicalObjectEdit
public:
/**
- * Creates a PMBicubicPatchEdit with tqparent and name
+ * Creates a PMBicubicPatchEdit with parent and name
*/